@@ -10,9 +10,21 @@ from django.utils.translation import gettext_lazy as _
 
 
 class ColombianCitiesBaseModel(models.Model):
-    created_at = models.DateTimeField(auto_now_add=True)
-    updated_at = models.DateTimeField(auto_now=True)
-    status = models.BooleanField("status", default=True)
+    created_at = models.DateTimeField(
+        _("Created at"),
+        help_text=_("Created at"),
+        auto_now_add=True,
+    )
+    updated_at = models.DateTimeField(
+        _("Updated at"),
+        help_text=_("Updated at"),
+        auto_now=True,
+    )
+    status = models.BooleanField(
+        _("Status"),
+        help_text=_("Status"),
+        default=True,
+    )
 
     class Meta:
         abstract = True
